Skip to contents

The intercept vector for the latent variables in the linear stochastic differential equation model \(\boldsymbol{\iota}\) is given by $$ \boldsymbol{\iota} = - \boldsymbol{\Phi} \mathrm{Mean} \left( \boldsymbol{\eta} \right) $$ where \(\boldsymbol{\Phi}\) is the drift matrix and \(\mathrm{Mean} \left( \boldsymbol{\eta} \right)\) is the steady-state mean vector for the latent variables.

Usage

LinSDEInterceptEta(phi, mean_eta)

Arguments

phi

Numeric matrix. The drift matrix which represents the rate of change of the solution in the absence of any random fluctuations (\(\boldsymbol{\Phi}\)).

mean_eta

Numeric vector. Steady-state mean vector of the latent variables \(\mathrm{Mean} \left( \boldsymbol{\eta} \right)\).

Author

Ivan Jacob Agaloos Pesigan

Examples

phi <- matrix(
  data = c(
    -0.357, 0.771, -0.450,
    0.0, -0.511, 0.729,
    0.0, 0.0, -0.693
  ),
  nrow = 3
)
iota <- rep(x = 1, times = 3)
lambda <- diag(3)
nu <- rep(x = 1, times = 3)
LinSDEMeanEta(
  phi = phi,
  iota = iota
)
#> [1] 2.801120 6.183295 6.128597