Skip to contents

The intercept vector for the observed variables in the linear stochastic differential equation model \(\boldsymbol{\nu}\) is given by $$ \boldsymbol{\nu} = \mathrm{Mean} \left( \mathbf{y} \right) - \boldsymbol{\Lambda} \mathrm{Mean} \left( \boldsymbol{\eta} \right) $$ where \(\boldsymbol{\Lambda}\) is the matrix of factor loadings, \(\mathrm{Mean} \left( \mathbf{y} \right)\) is the steady-state mean vector for the observed variables, and \(\mathrm{Mean} \left( \boldsymbol{\eta} \right)\) is the steady-state mean vector for the latent variables.

Usage

LinSDEInterceptY(mean_y, mean_eta, lambda)

Arguments

mean_y

Numeric vector. Steady-state mean vector of the observed variables \(\mathrm{Mean} \left( \mathbf{y} \right)\).

mean_eta

Numeric vector. Steady-state mean vector of the latent variables \(\mathrm{Mean} \left( \boldsymbol{\eta} \right)\).

lambda

Numeric matrix. Factor loading matrix linking the latent variables to the observed variables (\(\boldsymbol{\Lambda}\)).

Author

Ivan Jacob Agaloos Pesigan

Examples

phi <- matrix(
  data = c(
    -0.357, 0.771, -0.450,
    0.0, -0.511, 0.729,
    0.0, 0.0, -0.693
  ),
  nrow = 3
)
iota <- rep(x = 1, times = 3)
lambda <- diag(3)
nu <- rep(x = 1, times = 3)
mean_eta <- LinSDEMeanEta(
  phi = phi,
  iota = iota
)
mean_y <- LinSDEMeanY(
  nu = nu,
  lambda = lambda,
  mean_eta = mean_eta
)
LinSDEInterceptY(
  mean_y = mean_y,
  mean_eta = mean_eta,
  lambda = lambda
)
#> [1]  6.602241 13.366590 13.257195