The function computes the eigenvalues of the input matrix x.
It checks if all eigenvalues have moduli less than 1.
If all eigenvalues have moduli less than 1,
the system is considered stationary.
Usage
TestStationarity(x)
Arguments
x
Numeric matrix.
Author
Ivan Jacob Agaloos Pesigan
See Also
Other Simulation of State Space Models Data Functions:
LinSDE2SSM(),
SimBetaN(),
SimPhiN(),
SimSSMFixed(),
SimSSMIVary(),
SimSSMLinGrowth(),
SimSSMLinGrowthIVary(),
SimSSMLinSDEFixed(),
SimSSMLinSDEIVary(),
SimSSMOUFixed(),
SimSSMOUIVary(),
SimSSMVARFixed(),
SimSSMVARIVary(),
TestPhi(),
TestStability()