Learn R Programming

simStateSpace (version 1.2.3)

simStateSpace-package: simStateSpace: Simulate Data from State Space Models

Description

Provides a streamlined and user-friendly framework for simulating data in state space models, particularly when the number of subjects/units (n) exceeds one, a scenario commonly encountered in social and behavioral sciences. For an introduction to state space models in social and behavioral sciences, refer to Chow, Ho, Hamaker, and Dolan (2010) tools:::Rd_expr_doi("10.1080/10705511003661553").

Arguments

Author

Maintainer: Ivan Jacob Agaloos Pesigan r.jeksterslab@gmail.com (ORCID) [copyright holder]

See Also