Intercept from Steady-State Mean Vector for the Latent Variables in the Linear Stochastic Differential Equation Model
Source:R/simStateSpace-lin-sde-intercept-eta.R
LinSDEInterceptEta.RdThe intercept vector for the latent variables in the linear stochastic differential equation model \(\boldsymbol{\iota}\) is given by $$ \boldsymbol{\iota} = - \boldsymbol{\Phi} \mathrm{Mean} \left( \boldsymbol{\eta} \right) $$ where \(\boldsymbol{\Phi}\) is the drift matrix and \(\mathrm{Mean} \left( \boldsymbol{\eta} \right)\) is the steady-state mean vector for the latent variables.
See also
Other Simulation of State Space Models Data Functions:
LinSDE2SSM(),
LinSDECovEta(),
LinSDECovY(),
LinSDEInterceptY(),
LinSDEMeanEta(),
LinSDEMeanY(),
ProjectToHurwitz(),
ProjectToStability(),
SSMCovEta(),
SSMCovY(),
SSMInterceptEta(),
SSMInterceptY(),
SSMMeanEta(),
SSMMeanY(),
SimAlphaN(),
SimBetaN(),
SimBetaN2(),
SimBetaNCovariate(),
SimCovDiagN(),
SimCovN(),
SimIotaN(),
SimMVN(),
SimMuN(),
SimNuN(),
SimPhiN(),
SimPhiN2(),
SimPhiNCovariate(),
SimSSMFixed(),
SimSSMIVary(),
SimSSMLinGrowth(),
SimSSMLinGrowthIVary(),
SimSSMLinSDEFixed(),
SimSSMLinSDEIVary(),
SimSSMOUFixed(),
SimSSMOUIVary(),
SimSSMVARFixed(),
SimSSMVARIVary(),
SpectralRadius(),
TestPhi(),
TestPhiHurwitz(),
TestStability(),
TestStationarity()