Simulate Intercept Vectors in a Continuous-Time Vector Autoregressive Model from the Multivariate Normal Distribution
Source:R/simStateSpace-sim-mvn.R
SimIotaN.RdThis function simulates random intercept vectors in a continuous-time vector autoregressive model from the multivariate normal distribution.
See also
Other Simulation of State Space Models Data Functions:
LinSDE2SSM(),
LinSDECovEta(),
LinSDECovY(),
LinSDEInterceptEta(),
LinSDEInterceptY(),
LinSDEMeanEta(),
LinSDEMeanY(),
ProjectToHurwitz(),
ProjectToStability(),
SSMCovEta(),
SSMCovY(),
SSMInterceptEta(),
SSMInterceptY(),
SSMMeanEta(),
SSMMeanY(),
SimAlphaN(),
SimBetaN(),
SimBetaN2(),
SimBetaNCovariate(),
SimCovDiagN(),
SimCovN(),
SimMVN(),
SimMuN(),
SimNuN(),
SimPhiN(),
SimPhiN2(),
SimPhiNCovariate(),
SimSSMFixed(),
SimSSMIVary(),
SimSSMLinGrowth(),
SimSSMLinGrowthIVary(),
SimSSMLinSDEFixed(),
SimSSMLinSDEIVary(),
SimSSMOUFixed(),
SimSSMOUIVary(),
SimSSMVARFixed(),
SimSSMVARIVary(),
SpectralRadius(),
TestPhi(),
TestPhiHurwitz(),
TestStability(),
TestStationarity()
Examples
n <- 10
iota <- c(0, 0, 0)
vcov_iota_l <- t(chol(0.001 * diag(3)))
SimIotaN(n = n, iota = iota, vcov_iota_l = vcov_iota_l)
#> [[1]]
#> [1] 0.01854302 0.04752510 0.10891773
#>
#> [[2]]
#> [1] -0.001112522 0.011419870 0.021296500
#>
#> [[3]]
#> [1] 0.0001880568 -0.0254260549 0.0073114955
#>
#> [[4]]
#> [1] 0.0106630163 0.0007951237 0.0483638530
#>
#> [[5]]
#> [1] 0.03895627 0.01945489 -0.04111851
#>
#> [[6]]
#> [1] 0.037935872 -0.004766437 0.013510904
#>
#> [[7]]
#> [1] 0.02954862 0.04305909 0.02114061
#>
#> [[8]]
#> [1] 0.008611313 0.035027771 0.017578026
#>
#> [[9]]
#> [1] -0.01612411 0.05248648 -0.06911157
#>
#> [[10]]
#> [1] 0.062837536 0.004901415 0.042171823
#>