Both have to be true for the function to return TRUE.
Test that the real part of all eigenvalues of \(\boldsymbol{\Phi}\)
are less than zero.
Test that the diagonal values of \(\boldsymbol{\Phi}\)
are between 0 to negative inifinity.
Usage
TestPhi(phi)
Arguments
phi
Numeric matrix.
The drift matrix (\(\boldsymbol{\Phi}\)).
Author
Ivan Jacob Agaloos Pesigan
See Also
Other Simulation of State Space Models Data Functions:
LinSDE2SSM(),
SimBetaN(),
SimPhiN(),
SimSSMFixed(),
SimSSMIVary(),
SimSSMLinGrowth(),
SimSSMLinGrowthIVary(),
SimSSMLinSDEFixed(),
SimSSMLinSDEIVary(),
SimSSMOUFixed(),
SimSSMOUIVary(),
SimSSMVARFixed(),
SimSSMVARIVary(),
TestStability(),
TestStationarity()